Index: /trunk/psLib/test/collections/Makefile
===================================================================
--- /trunk/psLib/test/collections/Makefile	(revision 1226)
+++ /trunk/psLib/test/collections/Makefile	(revision 1227)
@@ -3,6 +3,6 @@
 ##  Makefile:   test/collections
 ##
-##  $Revision: 1.18 $  $Name: not supported by cvs2svn $
-##  $Date: 2004-07-13 01:37:58 $
+##  $Revision: 1.19 $  $Name: not supported by cvs2svn $
+##  $Date: 2004-07-15 22:17:03 $
 ##
 ##  Copyright 2004 Maui High Performance Computing Center, University of Hawaii
@@ -19,7 +19,6 @@
 LDFLAGS := -L../../lib -lpslib -lpstest $(LDFLAGS)
 
-TARGET = tst_psVector_01 \
-         tst_psVector_02 \
-         tst_psVector_03 \
+TARGET = tst_psVector \
+         tst_psArray \
          tst_psBitSet_01 \
          tst_psBitSet_02 \
Index: /trunk/psLib/test/collections/tst_psArray.c
===================================================================
--- /trunk/psLib/test/collections/tst_psArray.c	(revision 1227)
+++ /trunk/psLib/test/collections/tst_psArray.c	(revision 1227)
@@ -0,0 +1,155 @@
+/** @file  tst_psArray.c
+ *
+ *  @brief Test driver for psArray integer functions
+ *
+ *  This test driver contains the following tests for psArray test point 1:
+ *     A)  Create void pointer array
+ *     B)  Add data to void pointer array
+ *     C)  Reallocate void pointer array bigger
+ *     D)  Reallocate void pointer array smaller
+ *     E)  Free void pointer array
+ *
+ *  @author  Ross Harman, MHPCC
+ *
+ *  @version $Revision: 1.1 $  $Name: not supported by cvs2svn $
+ *  @date  $Date: 2004-07-15 22:17:03 $
+ *
+ *  Copyright 2004 Maui High Performance Computing Center, University of Hawaii
+ *
+ */
+
+#include <math.h>
+
+#include "pslib.h"
+#include "psTest.h"
+
+typedef struct
+{
+    int x;
+    float y;
+}
+testStruct;
+
+
+int main(int argc,
+         char* argv[])
+{
+    // Create array of pointers
+    testStruct *mySt[10];
+
+
+    // Test A - Create void pointer array
+    printPositiveTestHeader(stdout,"psArray", "Create void pointer array");
+    psArray *psArr = psArrayAlloc(5);
+    if (psArr->nalloc != 5) {
+        psError(__func__,"psArray didn't have proper number of elements.");
+        return 1;
+    }
+    printFooter(stdout, "psArray", "Create void pointer array", true);
+
+
+    // Test B - Add data to void pointer array
+    printPositiveTestHeader(stdout, "psArray", "Add data to void pointer array");
+    for(int i = 0; i < 5; i++) {
+        testStruct *ts = psAlloc(sizeof(testStruct));
+        ts->x = 10*i;
+        ts->y = 10.1*i;
+        mySt[i] = ts;
+        psArr->data[i] = ts;
+        psMemIncrRefCounter(ts);
+    }
+
+    for(int i = 0; i < 5; i++) {
+        testStruct *ts = (testStruct*)psArr->data[i];
+        printf("ts[%d].x = %d ts[%d].y = %.2f\n", i, ts->x, i, ts->y);
+        if (fabsf(ts->x - 10*i) > 0.01f || fabsf(ts->y - 10.1*i) > 0.01f) {
+            psError(__func__,"Couldn't properly get elements from array.");
+            return 2;
+        }
+    }
+    printf("array size = %d\n", psArr->nalloc);
+    if (psArr->nalloc != 5) {
+        psError(__func__,"Array Size wrong");
+        return 3;
+    }
+    printf("array population = %d\n", psArr->n);
+    if (psArr->n != 5) {
+        psError(__func__,"Array population wrong");
+        return 4;
+    }
+    printFooter(stdout, "psArray", "Add data to void pointer array", true);
+
+
+    // Test C - Reallocate void pointer array bigger
+    printPositiveTestHeader(stdout,"psArray", "Reallocate void pointer array bigger");
+    psArr = psArrayRealloc(10, psArr);
+    printf("Adding more elements to void pointer array...\n");
+    for(int i = 5; i < 10; i++) {
+        testStruct *ts = psAlloc(sizeof(testStruct));
+        ts->x = 10*i;
+        ts->y = 10.1*i;
+        mySt[i] = ts;
+        psArr->data[i] = ts;
+        psArr->n++;
+        psMemIncrRefCounter(ts);
+    }
+    for(int i = 0; i < 10; i++) {
+        testStruct *ts = (testStruct*)psArr->data[i];
+        printf("ts[%d].x = %d ts[%d].y = %.2f\n", i, ts->x, i, ts->y);
+        if (fabsf(ts->x - 10*i) > 0.01f || fabsf(ts->y - 10.1*i) > 0.01f) {
+            psError(__func__,"Couldn't properly get elements from array.");
+            return 5;
+        }
+    }
+    printf("array size = %d\n", psArr->nalloc);
+    if (psArr->nalloc != 10) {
+        psError(__func__,"Array Size wrong");
+        return 6;
+    }
+    printf("array population = %d\n", psArr->n);
+    if (psArr->n != 10) {
+        psError(__func__,"Array Population wrong");
+        return 7;
+    }
+    printFooter(stdout, "psArray", "Reallocate void pointer array bigger", true);
+
+
+    // Test D - Reallocate void pointer array smaller
+    printPositiveTestHeader(stdout,"psArray","Reallocate void pointer array smaller");
+    psArr = psArrayRealloc(3, psArr);
+    for(int i = 0; i < 3; i++) {
+        testStruct *ts = (testStruct*)psArr->data[i];
+        printf("ts[%d].x = %d ts[%d].y = %.2f\n", i, ts->x, i, ts->y);
+        if (fabsf(ts->x - 10*i) > 0.01f || fabsf(ts->y - 10.1*i) > 0.01f) {
+            psError(__func__,"Couldn't properly get elements from array.");
+            return 8;
+        }
+    }
+    printf("array size = %d\n", psArr->nalloc);
+    if (psArr->nalloc != 3) {
+        psError(__func__,"Array Size wrong");
+        return 9;
+    }
+    printf("array population = %d\n", psArr->n);
+    if (psArr->n != 3) {
+        psError(__func__,"Array Population wrong");
+        return 10;
+    }
+    printFooter(stdout, "psArray", "Reallocate integer void pointer smaller", true);
+
+
+    // Test E - Free void pointer array
+    printPositiveTestHeader(stdout, "psArray", "Free void pointer array");
+    psFree(psArr);
+    for(int i = 0; i < 10; i++) {
+        psFree(mySt[i]);
+    }
+    psMemCheckLeaks(0, NULL, stdout);
+    int nBad = psMemCheckCorruption(0);
+    if(nBad) {
+        printf("ERROR: Found %d bad memory blocks\n", nBad);
+    }
+    printFooter(stdout, "psArray" ,"Free void pointer array", true);
+
+    return 0;
+}
Index: unk/psLib/test/collections/tst_psVector_01.c
===================================================================
--- /trunk/psLib/test/collections/tst_psVector_01.c	(revision 1226)
+++ 	(revision )
@@ -1,105 +1,0 @@
-/** @file  tst_psVector_01.c
- *
- *  @brief Test driver for psVector integer functions
- *
- *  This test driver contains the following tests for psVector test point 1:
- *     A)  Create S32 vector
- *     B)  Add data to S32 vector
- *     C)  Reallocate S32 vector bigger
- *     D)  Reallocate S32 vector smaller
- *     E)  Free S32 vector
- *     F)  Attempt to create a S32 vector with zero size
- *     G)  Attempt to realloc a null S32 vector
- *
- *  @author  Ross Harman, MHPCC
- *
- *  @version $Revision: 1.10 $  $Name: not supported by cvs2svn $
- *  @date  $Date: 2004-06-29 02:32:09 $
- *
- *  Copyright 2004 Maui High Performance Computing Center, University of Hawaii
- *
- */
-
-#include "pslib.h"
-#include "psTest.h"
-
-int main(int argc,
-         char* argv[])
-{
-
-
-    // Test A - Create S32 vector
-    printPositiveTestHeader(stdout,"psVector", "Create S32 vector");
-    psVector *psVec = psVectorAlloc(5, PS_TYPE_S32);
-    printf("Vector size = %d\n", psVec->nalloc);
-    printf("Vector type = %d\n", psVec->type.type);
-    printf("Vector dimen = %d\n", psVec->type.dimen);
-    printFooter(stdout, "psVector", "Create S32 vector", true);
-
-
-    // Test B - Add data to integer vector
-    printPositiveTestHeader(stdout, "psVector", "Add data to S32 vector");
-    for(int i = 0; i < 5; i++) {
-        psVec->data.S32[i] = i*10;
-        printf("Elem %d = %d\n", i, psVec->data.S32[i]);
-    }
-    printf("Vector size = %d\n", psVec->nalloc);
-    printf("Vector population = %d\n", psVec->n);
-    printFooter(stdout, "psVector", "Add data to S32 vector", true);
-
-
-    // Test C - Reallocate S32 vector bigger
-    printPositiveTestHeader(stdout,"psVector", "Reallocate S32 vector bigger");
-    psVec = psVectorRealloc(10, psVec);
-    printf("Adding more elements to S32 vector...\n");
-    for(int i = 5; i < 10; i++) {
-        psVec->data.S32[i] = i*10;
-        psVec->n++;
-        printf("Elem %d = %d\n", i, psVec->data.S32[i]);
-    }
-    printf("Vector size = %d\n", psVec->nalloc);
-    printf("Vector population = %d\n", psVec->n);
-    printFooter(stdout, "psVector", "Reallocate S32 vector bigger", true);
-
-
-    // Test D - Reallocate S32 vector smaller
-    printPositiveTestHeader(stdout,"psVector","Reallocate S32 vector smaller");
-    psVec = psVectorRealloc(3, psVec);
-    printf("Vector size = %d\n", psVec->nalloc);
-    for(int i = 0; i < 3; i++) {
-        printf("Elem %d = %d\n", i, psVec->data.S32[i]);
-    }
-    printf("Vector size = %d\n", psVec->nalloc);
-    printf("Vector population = %d\n", psVec->n);
-    printFooter(stdout, "psVector", "Reallocate integer S32 smaller", true);
-
-
-    // Test E - Free S32 vector
-    printPositiveTestHeader(stdout, "psVector", "Free S32 vector");
-    psFree(psVec);
-    psMemCheckLeaks(0, NULL, stdout);
-    int nBad = psMemCheckCorruption(0);
-    if(nBad) {
-        printf("ERROR: Found %d bad memory blocks\n", nBad);
-    }
-    printFooter(stdout, "psVector" ,"Free S32 vector", true);
-
-
-    // Test F - Attempt to create a S32 vector with zero size
-    printNegativeTestHeader(stdout,"psVector", "Attempt to create a S32 vector with zero size",
-                            "Invalid value for nalloc", 0);
-    psVector *vecBad = psVectorAlloc(0, PS_TYPE_S32);
-    if(vecBad != NULL) {
-        printf("ERROR: Return is not NULL\n");
-    }
-    printFooter(stdout, "psVector", "Attempt to create a S32 vector with zero size", true);
-
-
-    // Test G - Attempt to realloc a null S32 vector
-    printNegativeTestHeader(stdout,"psVector", "Attempt to realloc a null S32 vector",
-                            "Null input vector", 0);
-    psVectorRealloc(6, NULL);
-    printFooter(stdout, "psVector", "Attempt to realloc a null S32 vector", true);
-
-    return 0;
-}
Index: unk/psLib/test/collections/tst_psVector_02.c
===================================================================
--- /trunk/psLib/test/collections/tst_psVector_02.c	(revision 1226)
+++ 	(revision )
@@ -1,117 +1,0 @@
-/** @file  tst_psVector_02.c
- *
- *  @brief Test driver for psVector integer functions
- *
- *  This test driver contains the following tests for psVector test point 1:
- *     A)  Create void pointer vector
- *     B)  Add data to void pointer vector
- *     C)  Reallocate void pointer vector bigger
- *     D)  Reallocate void pointer vector smaller
- *     E)  Free void pointer vector
- *
- *  @author  Ross Harman, MHPCC
- *
- *  @version $Revision: 1.5 $  $Name: not supported by cvs2svn $
- *  @date  $Date: 2004-06-30 22:45:15 $
- *
- *  Copyright 2004 Maui High Performance Computing Center, University of Hawaii
- *
- */
-
-#include "pslib.h"
-#include "psTest.h"
-
-typedef struct
-{
-    int x;
-    float y;
-}
-testStruct;
-
-
-int main(int argc,
-         char* argv[])
-{
-    // Create array of pointers
-    testStruct *mySt[10];
-
-
-    // Test A - Create void pointer vector
-    printPositiveTestHeader(stdout,"psVector", "Create void pointer vector");
-    psVector *psVec = psVectorAlloc(5, PS_TYPE_PTR);
-    printf("Vector size = %d\n", psVec->nalloc);
-    printf("Vector type = %d\n", psVec->type.type);
-    printf("Vector dimen = %d\n", psVec->type.dimen);
-    printFooter(stdout, "psVector", "Create void pointer vector", true);
-
-
-    // Test B - Add data to void pointer vector
-    printPositiveTestHeader(stdout, "psVector", "Add data to void pointer vector");
-    for(int i = 0; i < 5; i++) {
-        testStruct *ts = psAlloc(sizeof(testStruct));
-        ts->x = 10*i;
-        ts->y = 10.1*i;
-        mySt[i] = ts;
-        psVec->data.PTR[i] = ts;
-        psMemIncrRefCounter(ts);
-    }
-
-    for(int i = 0; i < 5; i++) {
-        testStruct *ts = (testStruct*)psVec->data.PTR[i];
-        printf("ts[%d].x = %d ts[%d].y = %.2f\n", i, ts->x, i, ts->y);
-    }
-    printf("Vector size = %d\n", psVec->nalloc);
-    printf("Vector population = %d\n", psVec->n);
-    printFooter(stdout, "psVector", "Add data to void pointer vector", true);
-
-
-    // Test C - Reallocate void pointer vector bigger
-    printPositiveTestHeader(stdout,"psVector", "Reallocate void pointer vector bigger");
-    psVec = psVectorRealloc(10, psVec);
-    printf("Adding more elements to void pointer vector...\n");
-    for(int i = 5; i < 10; i++) {
-        testStruct *ts = psAlloc(sizeof(testStruct));
-        ts->x = 10*i;
-        ts->y = 10.1*i;
-        mySt[i] = ts;
-        psVec->data.PTR[i] = ts;
-        psVec->n++;
-        psMemIncrRefCounter(ts);
-    }
-    for(int i = 0; i < 10; i++) {
-        testStruct *ts = (testStruct*)psVec->data.PTR[i];
-        printf("ts[%d].x = %d ts[%d].y = %.2f\n", i, ts->x, i, ts->y);
-    }
-    printf("Vector size = %d\n", psVec->nalloc);
-    printf("Vector population = %d\n", psVec->n);
-    printFooter(stdout, "psVector", "Reallocate void pointer vector bigger", true);
-
-
-    // Test D - Reallocate void pointer vector smaller
-    printPositiveTestHeader(stdout,"psVector","Reallocate void pointer vector smaller");
-    psVec = psVectorRealloc(3, psVec);
-    for(int i = 0; i < 3; i++) {
-        testStruct *ts = (testStruct*)psVec->data.PTR[i];
-        printf("ts[%d].x = %d ts[%d].y = %.2f\n", i, ts->x, i, ts->y);
-    }
-    printf("Vector size = %d\n", psVec->nalloc);
-    printf("Vector population = %d\n", psVec->n);
-    printFooter(stdout, "psVector", "Reallocate integer void pointer smaller", true);
-
-
-    // Test E - Free void pointer vector
-    printPositiveTestHeader(stdout, "psVector", "Free void pointer vector");
-    psVectorElementFree(psVec);
-    psFree(psVec);
-    for(int i = 0; i < 10; i++) {
-        psFree(mySt[i]);
-    }
-    psMemCheckLeaks(0, NULL, stdout);
-    int nBad = psMemCheckCorruption(0);
-    if(nBad) {
-        printf("ERROR: Found %d bad memory blocks\n", nBad);
-    }
-    printFooter(stdout, "psVector" ,"Free void pointer vector", true);
-
-    return 0;
-}
Index: unk/psLib/test/collections/tst_psVector_03.c
===================================================================
--- /trunk/psLib/test/collections/tst_psVector_03.c	(revision 1226)
+++ 	(revision )
@@ -1,114 +1,0 @@
-/** @file  tst_psVector_03.c
- *
- *  @brief Test driver for psVector integer functions
- *
- *  This test driver contains the following tests for psVector test point 3:
- *     A)  Create void pointer vector
- *     B)  Add data to void pointer vector
- *     C)  Reallocate void pointer vector bigger
- *     D)  Reallocate void pointer vector smaller
- *     E)  Free void pointer array with function callback
- *
- *  @author  Ross Harman, MHPCC
- *
- *  @version $Revision: 1.7 $  $Name: not supported by cvs2svn $
- *  @date  $Date: 2004-06-30 22:48:23 $
- *
- *  Copyright 2004 Maui High Performance Computing Center, University of Hawaii
- *
- */
-
-#include "pslib.h"
-#include "psTest.h"
-
-typedef struct
-{
-    int x;
-    float y;
-}
-testStruct;
-
-int main(int argc,
-         char* argv[])
-{
-    // Create array of pointers
-    testStruct *mySt[10];
-
-
-    // Test A - Create void pointer vector
-    printPositiveTestHeader(stdout,"psVector", "Create void pointer vector");
-    psVector *psVec = psVectorAlloc(5, PS_TYPE_PTR);
-    printf("Vector size = %d\n", psVec->nalloc);
-    printf("Vector type = %d\n", psVec->type.type);
-    printf("Vector dimen = %d\n", psVec->type.dimen);
-    printFooter(stdout, "psVector", "Create void pointer vector", true);
-
-
-    // Test B - Add data to void pointer vector
-    printPositiveTestHeader(stdout, "psVector", "Add data to void pointer vector");
-    for(int i = 0; i < 5; i++) {
-        testStruct *ts = psAlloc(sizeof(testStruct));
-        ts->x = 10*i;
-        ts->y = 10.1*i;
-        mySt[i] = ts;
-        psVec->data.PTR[i] = ts;
-    }
-
-    for(int i = 0; i < 5; i++) {
-        testStruct *ts = (testStruct*)psVec->data.PTR[i];
-        printf("ts[%d].x = %d ts[%d].y = %.2f\n", i, ts->x, i, ts->y);
-    }
-    printf("Vector size = %d\n", psVec->nalloc);
-    printf("Vector population = %d\n", psVec->n);
-    printFooter(stdout, "psVector", "Add data to void pointer vector", true);
-
-
-    // Test C - Reallocate void pointer vector bigger
-    printPositiveTestHeader(stdout,"psVector", "Reallocate void pointer vector bigger");
-    psVec = psVectorRealloc(10, psVec);
-    printf("Adding more elements to void pointer vector...\n");
-    for(int i = 5; i < 10; i++) {
-        testStruct *ts = psAlloc(sizeof(testStruct));
-        ts->x = 10*i;
-        ts->y = 10.1*i;
-        mySt[i] = ts;
-        psVec->data.PTR[i] = ts;
-        psVec->n++;
-    }
-    for(int i = 0; i < 10; i++) {
-        testStruct *ts = (testStruct*)psVec->data.PTR[i];
-        printf("ts[%d].x = %d ts[%d].y = %.2f\n", i, ts->x, i, ts->y);
-    }
-    printf("Vector size = %d\n", psVec->nalloc);
-    printf("Vector population = %d\n", psVec->n);
-    printFooter(stdout, "psVector", "Reallocate void pointer vector bigger", true);
-
-    // Test D - Reallocate void pointer vector smaller
-    printPositiveTestHeader(stdout,"psVector","Reallocate void pointer vector smaller");
-    psVec = psVectorRealloc(3, psVec); // this also frees the elements trimmed
-    for(int i = 0; i < 3; i++) {
-        testStruct *ts = (testStruct*)psVec->data.PTR[i];
-        printf("ts[%d].x = %d ts[%d].y = %.2f\n", i, ts->x, i, ts->y);
-    }
-    printf("Vector size = %d\n", psVec->nalloc);
-    printf("Vector population = %d\n", psVec->n);
-    printFooter(stdout, "psVector", "Reallocate integer void pointer smaller", true);
-
-
-    // Test E - Free void pointer array with function callback
-    printPositiveTestHeader(stdout, "psVector", "Free void pointer array with function callback");
-
-    // Free void pointer array struct and its 3 internal elements
-    psFree(psVec);
-
-    if (psMemCheckLeaks(0, NULL, stdout) != 0) {
-        psAbort(__func__,"memory leaks");
-    }
-    int nBad = psMemCheckCorruption(0);
-    if(nBad) {
-        printf("ERROR: Found %d bad memory blocks\n", nBad);
-    }
-    printFooter(stdout, "psVector" ,"Free void pointer array with function callback", true);
-
-    return 0;
-}
Index: /trunk/psLib/test/collections/verified/tst_psArray.stdout
===================================================================
--- /trunk/psLib/test/collections/verified/tst_psArray.stdout	(revision 1227)
+++ /trunk/psLib/test/collections/verified/tst_psArray.stdout	(revision 1227)
@@ -0,0 +1,70 @@
+/***************************** TESTPOINT ******************************************\
+*             TestFile: tst_psArray.c                                              *
+*            TestPoint: psArray{Create void pointer array}                         *
+*             TestType: Positive                                                   *
+\**********************************************************************************/
+
+
+---> TESTPOINT PASSED (psArray{Create void pointer array} | tst_psArray.c)
+
+/***************************** TESTPOINT ******************************************\
+*             TestFile: tst_psArray.c                                              *
+*            TestPoint: psArray{Add data to void pointer array}                    *
+*             TestType: Positive                                                   *
+\**********************************************************************************/
+
+ts[0].x = 0 ts[0].y = 0.00
+ts[1].x = 10 ts[1].y = 10.10
+ts[2].x = 20 ts[2].y = 20.20
+ts[3].x = 30 ts[3].y = 30.30
+ts[4].x = 40 ts[4].y = 40.40
+array size = 5
+array population = 5
+
+---> TESTPOINT PASSED (psArray{Add data to void pointer array} | tst_psArray.c)
+
+/***************************** TESTPOINT ******************************************\
+*             TestFile: tst_psArray.c                                              *
+*            TestPoint: psArray{Reallocate void pointer array bigger}              *
+*             TestType: Positive                                                   *
+\**********************************************************************************/
+
+Adding more elements to void pointer array...
+ts[0].x = 0 ts[0].y = 0.00
+ts[1].x = 10 ts[1].y = 10.10
+ts[2].x = 20 ts[2].y = 20.20
+ts[3].x = 30 ts[3].y = 30.30
+ts[4].x = 40 ts[4].y = 40.40
+ts[5].x = 50 ts[5].y = 50.50
+ts[6].x = 60 ts[6].y = 60.60
+ts[7].x = 70 ts[7].y = 70.70
+ts[8].x = 80 ts[8].y = 80.80
+ts[9].x = 90 ts[9].y = 90.90
+array size = 10
+array population = 10
+
+---> TESTPOINT PASSED (psArray{Reallocate void pointer array bigger} | tst_psArray.c)
+
+/***************************** TESTPOINT ******************************************\
+*             TestFile: tst_psArray.c                                              *
+*            TestPoint: psArray{Reallocate void pointer array smaller}             *
+*             TestType: Positive                                                   *
+\**********************************************************************************/
+
+ts[0].x = 0 ts[0].y = 0.00
+ts[1].x = 10 ts[1].y = 10.10
+ts[2].x = 20 ts[2].y = 20.20
+array size = 3
+array population = 3
+
+---> TESTPOINT PASSED (psArray{Reallocate integer void pointer smaller} | tst_psArray.c)
+
+/***************************** TESTPOINT ******************************************\
+*             TestFile: tst_psArray.c                                              *
+*            TestPoint: psArray{Free void pointer array}                           *
+*             TestType: Positive                                                   *
+\**********************************************************************************/
+
+
+---> TESTPOINT PASSED (psArray{Free void pointer array} | tst_psArray.c)
+
Index: /trunk/psLib/test/collections/verified/tst_psVector.stderr
===================================================================
--- /trunk/psLib/test/collections/verified/tst_psVector.stderr	(revision 1227)
+++ /trunk/psLib/test/collections/verified/tst_psVector.stderr	(revision 1227)
@@ -0,0 +1,4 @@
+ <DATE> <TIME> |<HOST>|I|           main|Following should be an error message.
+ <DATE> <TIME> |<HOST>|E|  psVectorAlloc|Invalid value for nalloc. nalloc: 0
+ <DATE> <TIME> |<HOST>|I|           main|Following should be an error message.
+ <DATE> <TIME> |<HOST>|E|psVectorRealloc|Null input vector
Index: /trunk/psLib/test/collections/verified/tst_psVector.stdout
===================================================================
--- /trunk/psLib/test/collections/verified/tst_psVector.stdout	(revision 1227)
+++ /trunk/psLib/test/collections/verified/tst_psVector.stdout	(revision 1227)
@@ -0,0 +1,91 @@
+/***************************** TESTPOINT ******************************************\
+*             TestFile: tst_psVector.c                                             *
+*            TestPoint: psVector{Create S32 vector}                                *
+*             TestType: Positive                                                   *
+\**********************************************************************************/
+
+Vector size = 5
+Vector type = 260
+Vector dimen = 1
+
+---> TESTPOINT PASSED (psVector{Create S32 vector} | tst_psVector.c)
+
+/***************************** TESTPOINT ******************************************\
+*             TestFile: tst_psVector.c                                             *
+*            TestPoint: psVector{Add data to S32 vector}                           *
+*             TestType: Positive                                                   *
+\**********************************************************************************/
+
+Elem 0 = 0
+Elem 1 = 10
+Elem 2 = 20
+Elem 3 = 30
+Elem 4 = 40
+Vector size = 5
+Vector population = 5
+
+---> TESTPOINT PASSED (psVector{Add data to S32 vector} | tst_psVector.c)
+
+/***************************** TESTPOINT ******************************************\
+*             TestFile: tst_psVector.c                                             *
+*            TestPoint: psVector{Reallocate S32 vector bigger}                     *
+*             TestType: Positive                                                   *
+\**********************************************************************************/
+
+Adding more elements to S32 vector...
+Elem 5 = 50
+Elem 6 = 60
+Elem 7 = 70
+Elem 8 = 80
+Elem 9 = 90
+Vector size = 10
+Vector population = 10
+
+---> TESTPOINT PASSED (psVector{Reallocate S32 vector bigger} | tst_psVector.c)
+
+/***************************** TESTPOINT ******************************************\
+*             TestFile: tst_psVector.c                                             *
+*            TestPoint: psVector{Reallocate S32 vector smaller}                    *
+*             TestType: Positive                                                   *
+\**********************************************************************************/
+
+Vector size = 3
+Elem 0 = 0
+Elem 1 = 10
+Elem 2 = 20
+Vector size = 3
+Vector population = 3
+
+---> TESTPOINT PASSED (psVector{Reallocate integer S32 smaller} | tst_psVector.c)
+
+/***************************** TESTPOINT ******************************************\
+*             TestFile: tst_psVector.c                                             *
+*            TestPoint: psVector{Free S32 vector}                                  *
+*             TestType: Positive                                                   *
+\**********************************************************************************/
+
+
+---> TESTPOINT PASSED (psVector{Free S32 vector} | tst_psVector.c)
+
+/***************************** TESTPOINT ******************************************\
+*             TestFile: tst_psVector.c                                             *
+*            TestPoint: psVector{Attempt to create a S32 vector with zero size}    *
+*             TestType: Negative                                                   *
+*    ExpectedErrorText: Invalid value for nalloc                                   *
+*  ExpectedStatusValue: 0                                                          *
+\**********************************************************************************/
+
+
+---> TESTPOINT PASSED (psVector{Attempt to create a S32 vector with zero size} | tst_psVector.c)
+
+/***************************** TESTPOINT ******************************************\
+*             TestFile: tst_psVector.c                                             *
+*            TestPoint: psVector{Attempt to realloc a null S32 vector}             *
+*             TestType: Negative                                                   *
+*    ExpectedErrorText: Null input vector                                          *
+*  ExpectedStatusValue: 0                                                          *
+\**********************************************************************************/
+
+
+---> TESTPOINT PASSED (psVector{Attempt to realloc a null S32 vector} | tst_psVector.c)
+

Index: /trunk/psLib/test/collections/tst_psList.c
===================================================================
--- /trunk/psLib/test/collections/tst_psList.c	(revision 1226)
+++ /trunk/psLib/test/collections/tst_psList.c	(revision 1227)
@@ -6,6 +6,6 @@
  *  @author Robert DeSonia, MHPCC
  *
- *  @version $Revision: 1.13 $ $Name: not supported by cvs2svn $
- *  @date $Date: 2004-07-08 01:05:01 $
+ *  @version $Revision: 1.14 $ $Name: not supported by cvs2svn $
+ *  @date $Date: 2004-07-15 22:17:03 $
  *
  *  Copyright 2004 Maui High Performance Computing Center, University of Hawaii
@@ -686,5 +686,5 @@
 
     psList* list = NULL;
-    psVector* vec = NULL;
+    psArray* arr = NULL;
     int* data;
 
@@ -695,5 +695,5 @@
     */
 
     // test dlist -> vector
 
     // create a list
@@ -706,103 +706,103 @@
     }
 
-    vec = psListToVector(list);
-
-    if (vec->n != 15 || list->size != 15) {
-        psError(__func__,"The created vector didn't have the proper size");
-        return 1;
-    }
-    for (int i=0;i<vec->n;i++) {
-        if (i != *(int*)vec->data.PTR[i]) {
-            psError(__func__,"Element %d of vector is incorrect (%d).",
-                    i,*(int*)vec->data.PTR[i]);
+    arr = psListToArray(list);
+
+    if (arr->n != 15 || list->size != 15) {
+        psError(__func__,"The created array didn't have the proper size");
+        return 1;
+    }
+    for (int i=0;i<arr->n;i++) {
+        if (i != *(int*)arr->data[i]) {
+            psError(__func__,"Element %d of array is incorrect (%d).",
+                    i,*(int*)arr->data[i]);
             return 1;
         }
         if (i != *(int*)psListGet(list,i)) {
             psError(__func__,"Element %d of list is incorrect (%d).",
-                    i,*(int*)vec->data.PTR[i]);
+                    i,*(int*)arr->data[i]);
             return 1;
         }
-        if (psMemGetRefCounter(vec->data.PTR[i]) != 2) {
+        if (psMemGetRefCounter(arr->data[i]) != 2) {
             psError(__func__,"Element %d had wrong reference count (%d).",
-                    i,psMemGetRefCounter(vec->data.PTR[i]));
+                    i,psMemGetRefCounter(arr->data[i]));
             return 1;
         }
     }
 
-    psFree(vec);
-    psFree(list);
-
-    // test vector -> dlist
-
-    // create a vector
-    vec = psVectorAlloc(15,PS_TYPE_PTR);
-    vec->n = vec->nalloc;
+    psFree(arr);
+    psFree(list);
+
+    // test array -> dlist
+
+    // create an array
+    arr = psArrayAlloc(15);
+    arr->n = arr->nalloc;
     for (int lcv=0;lcv<15;lcv++) {
         data = psAlloc(sizeof(int));
         *data = lcv;
-        vec->data.PTR[lcv] = data;
-    }
-
-    list = psVectorToList(vec);
-
-    if (vec->n != 15 || list->size != 15) {
-        psError(__func__,"The created vector didn't have the proper size");
-        return 1;
-    }
-    for (int i=0;i<vec->n;i++) {
-        if (i != *(int*)vec->data.PTR[i]) {
-            psError(__func__,"Element %d of vector is incorrect (%d).",
-                    i,*(int*)vec->data.PTR[i]);
+        arr->data[lcv] = data;
+    }
+
+    list = psArrayToList(arr);
+
+    if (arr->n != 15 || list->size != 15) {
+        psError(__func__,"The created array didn't have the proper size");
+        return 1;
+    }
+    for (int i=0;i<arr->n;i++) {
+        if (i != *(int*)arr->data[i]) {
+            psError(__func__,"Element %d of array is incorrect (%d).",
+                    i,*(int*)arr->data[i]);
             return 1;
         }
         if (i != *(int*)psListGet(list,i)) {
             psError(__func__,"Element %d of list is incorrect (%d).",
-                    i,*(int*)vec->data.PTR[i]);
+                    i,*(int*)arr->data[i]);
             return 1;
         }
-        if (psMemGetRefCounter(vec->data.PTR[i]) != 2) {
+        if (psMemGetRefCounter(arr->data[i]) != 2) {
             psError(__func__,"Element %d had wrong reference count (%d).",
-                    i,psMemGetRefCounter(vec->data.PTR[i]));
+                    i,psMemGetRefCounter(arr->data[i]));
             return 1;
         }
     }
 
-    psFree(vec);
-    psFree(list);
-
-    // now, make sure if input vector/list is NULL, output is NULL
-
-    vec = psListToVector(NULL);
-    if (vec != NULL) {
-        psError(__func__,"psListToVector didn't return NULL when given NULL");
-        return 1;
-    }
-
-    list = psVectorToList(NULL);
+    psFree(arr);
+    psFree(list);
+
+    // now, make sure if input array/list is NULL, output is NULL
+
+    arr = psListToArray(NULL);
+    if (arr != NULL) {
+        psError(__func__,"psListToArray didn't return NULL when given NULL");
+        return 1;
+    }
+
+    list = psArrayToList(NULL);
     if (list != NULL) {
-        psError(__func__,"psVectorToList didn't return NULL when given NULL");
-        return 1;
-    }
-
-    // now, see what happens with a zero-size vector/list
-    vec = psVectorAlloc(1,PS_TYPE_PTR);
-    vec->n = 0;
-    list = psVectorToList(vec);
+        psError(__func__,"psArrayToList didn't return NULL when given NULL");
+        return 1;
+    }
+
+    // now, see what happens with a zero-size array/list
+    arr = psArrayAlloc(1);
+    arr->n = 0;
+    list = psArrayToList(arr);
     if (list == NULL) {
-        psError(__func__,"psVectorToList didn't create an empty list from an "
-                "empty vector.");
-        return 1;
-    }
-    psFree(vec);
+        psError(__func__,"psArrayToList didn't create an empty list from an "
+                "empty array.");
+        return 1;
+    }
+    psFree(arr);
     psFree(list);
 
     list = psListAlloc(NULL);
-    vec = psListToVector(list);
-    if (vec == NULL) {
-        psError(__func__,"psVectorToList didn't create an empty vector from an "
+    arr = psListToArray(list);
+    if (arr == NULL) {
+        psError(__func__,"psArrayToList didn't create an empty array from an "
                 "empty list.");
         return 1;
     }
-    psFree(vec);
+    psFree(arr);
     psFree(list);
 
@@ -695,5 +695,5 @@
     */
 
-    // test dlist -> vector
+    // test dlist -> array
 
     // create a list